aboutsummaryrefslogtreecommitdiffstats
path: root/Source/SPWindowController.m
diff options
context:
space:
mode:
Diffstat (limited to 'Source/SPWindowController.m')
-rw-r--r--Source/SPWindowController.m3
1 files changed, 2 insertions, 1 deletions
diff --git a/Source/SPWindowController.m b/Source/SPWindowController.m
index 5b6b7732..1876d11a 100644
--- a/Source/SPWindowController.m
+++ b/Source/SPWindowController.m
@@ -284,8 +284,9 @@
// Update the old window
[[draggedFromWindow windowController] updateSelectedTableDocument];
// Update the item's document's window
[draggedDocument willResignActiveTabInWindow];
+ [draggedDocument setParentWindowController:[[tabBarControl window] windowController]];
[draggedDocument setParentWindow:[tabBarControl window]];
[draggedDocument didBecomeActiveTabInWindow];
@@ -284,8 +284,9 @@
// Update the old window
[[draggedFromWindow windowController] updateSelectedTableDocument];
- // Update the item's document's window
+ // Update the item's document's window and controller
[draggedDocument willResignActiveTabInWindow];